@@ -1126,9 +1126,11 @@ extern int create_server_ssl_connection(struct client_state *csp)
    }
 #endif
    /* SNI extension */
-   if (!SSL_set_tlsext_host_name(ssl, csp->http->host))
+   if (!host_is_ip_address(csp->http->host) &&
+       !SSL_set_tlsext_host_name(ssl, csp->http->host))
    {
-      log_ssl_errors(LOG_LEVEL_ERROR, "SSL_set_tlsext_host_name failed");
+      log_ssl_errors(LOG_LEVEL_ERROR,
+         "SSL_set_tlsext_host_name() failed to set %s", csp->http->host);
       ret = -1;
       goto exit;
    }
@@ -1288,7 +1290,7 @@ static void log_ssl_errors(int debuglevel, const char* fmt, ...)
  *          4  :  src = Source buffer
  *          5  :  slen = Amount of data to be encoded
  *
- * Returns     :  0 on success, error code othervise
+ * Returns     :  0 on success, error code otherwise
  *
  *********************************************************************/
 extern int ssl_base64_encode(unsigned char *dst, size_t dlen, size_t *olen,
