@@ -63,10 +63,7 @@ extern jb_err sed_https(struct client_state *csp);
 extern jb_err header_adjust_content_length(char **header, size_t content_length);
 extern jb_err update_server_headers(struct client_state *csp);
 extern void get_http_time(int time_offset, char *buf, size_t buffer_size);
-extern jb_err get_destination_from_headers(const struct list *headers, struct http_request *http);
-#ifdef FEATURE_HTTPS_INSPECTION
-extern jb_err get_destination_from_https_headers(const struct list *headers, struct http_request *http);
-#endif
+extern jb_err get_destination_from_headers(const struct list *headers, struct http_request *http, int https_request);
 extern unsigned long long get_expected_content_length(struct list *headers);
 extern jb_err client_transfer_encoding(struct client_state *csp, char **header);
 
