@@ -103,38 +103,20 @@
  */
 
 #ifdef STATIC_PCRE
-#ifdef HAVE_PCRE2
 #  include "pcre2.h"
 #  include "pcre2posix.h"
 #else
-#  include "pcre.h"
-#  include "pcreposix.h"
-#endif
-#else
-#  ifdef HAVE_PCRE2
-#    ifdef PCRE2_H_IN_SUBDIR
-#      define PCRE2_CODE_UNIT_WIDTH 8
-#      include <pcre2/pcre2.h>
-#    else
-#      define PCRE2_CODE_UNIT_WIDTH 8
-#      include <pcre2.h>
-#    endif
-#    ifdef PCRE2POSIX_H_IN_SUBDIR
-#        include <pcre2/pcre2posix.h>
-#    else
-#        include <pcre2posix.h>
-#    endif
+#  ifdef PCRE2_H_IN_SUBDIR
+#    define PCRE2_CODE_UNIT_WIDTH 8
+#    include <pcre2/pcre2.h>
 #  else
-#    ifdef PCRE_H_IN_SUBDIR
-#      include <pcre/pcre.h>
-#    else
-#      include <pcre.h>
-#    endif
-#    ifdef PCREPOSIX_H_IN_SUBDIR
-#        include <pcre/pcreposix.h>
-#    else
-#        include <pcreposix.h>
-#    endif
+#    define PCRE2_CODE_UNIT_WIDTH 8
+#    include <pcre2.h>
+#  endif
+#  ifdef PCRE2POSIX_H_IN_SUBDIR
+#      include <pcre2/pcre2posix.h>
+#  else
+#      include <pcre2posix.h>
 #  endif
 #endif
 
@@ -440,16 +422,10 @@ struct http_response
   enum crunch_reason crunch_reason; /**< Why the response was generated in the first place. */
 };
 
-#ifdef HAVE_PCRE2
-#define REGEX_TYPE pcre2_code
-#else
-#define REGEX_TYPE regex_t
-#endif
-
 struct url_spec
 {
 #ifdef FEATURE_PCRE_HOST_PATTERNS
-   REGEX_TYPE *host_regex;/**< Regex for host matching                          */
+   pcre2_code *host_regex;/**< Regex for host matching                          */
    enum host_regex_type { VANILLA_HOST_PATTERN, PCRE_HOST_PATTERN } host_regex_type;
 #endif /* defined FEATURE_PCRE_HOST_PATTERNS */
    int    dcount;      /**< How many parts to this domain? (length of dvec)   */
@@ -459,7 +435,7 @@ struct url_spec
 
    char  *port_list;   /**< List of acceptable ports, or NULL to match all ports */
 
-  REGEX_TYPE *preg;    /**< Regex for matching path part                      */
+   pcre2_code *preg;    /**< Regex for matching path part                      */
 };
 
 /**
@@ -474,7 +450,7 @@ struct pattern_spec
    union
    {
       struct url_spec url_spec;
-      REGEX_TYPE *tag_regex;
+      pcre2_code *tag_regex;
    } pattern;
 
    unsigned int flags; /**< Bitmap with various pattern properties. */
@@ -537,13 +513,14 @@ struct iob
 #define CT_GZIP    0x0010U /**< gzip-compressed data. */
 #define CT_DEFLATE 0x0020U /**< zlib-compressed data. */
 #define CT_BROTLI  0x0040U /**< Brotli-compressed data. */
+#define CT_ZSTD    0x0080U /**< Zstandard-compressed data. */
 
 /**
  * Flag to signal that the server declared the content type,
  * so we can differentiate between unknown and undeclared
  * content types.
  */
-#define CT_DECLARED 0x0080U
+#define CT_DECLARED 0x0100U
 
 /**
  * The mask which includes all actions.
