@@ -6,7 +6,7 @@
  *                creating, using and closing TLS/SSL connections
  *                using wolfSSL.
  *
- * Copyright   :  Copyright (C) 2018-2024 by Fabian Keil <fk@fabiankeil.de>
+ * Copyright   :  Copyright (C) 2018-2025 by Fabian Keil <fk@fabiankeil.de>
  *                Copyright (C) 2020 Maxim Antonov <mantonov@gmail.com>
  *                Copyright (C) 2017 Vaclav Svec. FIT CVUT.
  *
@@ -1086,7 +1086,7 @@ extern int create_server_ssl_connection(struct client_state *csp)
    csp->server_cert_verification_result = SSL_CERT_NOT_VERIFIED;
    csp->server_certs_chain.next = NULL;
 
-   ssl_attrs->ctx = wolfSSL_CTX_new(wolfSSLv23_method());
+   ssl_attrs->ctx = wolfSSL_CTX_new(wolfTLS_client_method());
    if (ssl_attrs->ctx == NULL)
    {
       log_error(LOG_LEVEL_ERROR, "TLS context creation failed");
@@ -1153,15 +1153,13 @@ extern int create_server_ssl_connection(struct client_state *csp)
    }
 
 #ifdef HAVE_SECURE_RENEGOTIATION
-#warning wolfssl has been compiled with HAVE_SECURE_RENEGOTIATION while you probably want HAVE_RENEGOTIATION_INDICATION
    if(wolfSSL_UseSecureRenegotiation(ssl) != WOLFSSL_SUCCESS)
    {
       log_error(LOG_LEVEL_ERROR,
          "Failed to enable 'Secure' Renegotiation. Continuing anyway.");
    }
-#endif
-#ifndef HAVE_RENEGOTIATION_INDICATION
-#warning Looks like wolfssl has been compiled without HAVE_RENEGOTIATION_INDICATION
+#else
+#warning Looks like wolfSSL has been compiled without HAVE_SECURE_RENEGOTIATION
 #endif
 
    log_error(LOG_LEVEL_CONNECT,
@@ -1208,8 +1206,8 @@ extern int create_server_ssl_connection(struct client_state *csp)
                   log_error(LOG_LEVEL_ERROR,
                      "ssl_store_cert() failed for cert %d", i);
                   /*
-                   * ssl_send_certificate_error() wil not be able to show
-                   * the certificate but the user will stil get the error
+                   * ssl_send_certificate_error() will not be able to show
+                   * the certificate but the user will still get the error
                    * description.
                    */
                }
@@ -1334,7 +1332,7 @@ static void log_ssl_errors(int debuglevel, const char* fmt, ...)
  *          4  :  src = Source buffer
  *          5  :  slen = Amount of data to be encoded
  *
- * Returns     :  0 on success, error code othervise
+ * Returns     :  0 on success, error code otherwise
  *
  *********************************************************************/
 extern int ssl_base64_encode(unsigned char *dst, size_t dlen, size_t *olen,
@@ -1774,7 +1772,7 @@ static int set_subject_alternative_name(struct Cert *certificate, const char *ho
  *
  * Parameters  :
  *          1  :  csp = Current client state (buffers, headers, etc...)
- *          2  :  certificate_path = Path to the certficate to generate.
+ *          2  :  certificate_path = Path to the certificate to generate.
  *          3  :  rsa_key_path = Path to the key to generate for the
  *                               certificate.
  *
